==> masm-util-0.0.1.tgz: package/main.js <==
var _ = require("underscore");

function jsonToUrlQuery(obj) {
    var query = [];
    _.each(obj, function(value, key) {
	query.push(key + "=" + encodeURIComponent(value));
    });
    return query.join("&");
}

function url(path, obj) {
    var query = jsonToUrlQuery(obj);
    if (query === "") {
        return path;
    } else {
        return path + "?" + query;
    }
}

function withJSONFromBody(callback) {
    return function(res) {
        var buffer = [];
        res.setEncoding("utf8");
        res.on("data", function(data) {
            buffer.push(data);
        });
        res.on("end", function() {
            var obj;
            try {
                obj = JSON.parse(buffer.join(""));
            } catch (e) {
                obj = { error: "internal server error", reason: "not an expected json body"};
            }
            callback(obj);
        });
    };
}

function withFieldsChecked(body, spec, callback) {
    return callback(checkFields(body, spec));
}

function checkFields(obj, fieldSpecs, type) {
    for (var i = 0; i < fieldSpecs.length; i++) {
        var fieldSpec = fieldSpecs[i];
        var fieldName, fieldType, cond, reason;
        cond   = fieldName = fieldSpec[0];
        reason = fieldType = fieldSpec[1];
        if (typeof cond == "boolean") {
            if (!cond) {
                return {error: "bad object", reason: reason};
            }
        } else if (typeof obj[fieldName] !== fieldType) {
            return {error: "bad object", reason: fieldName + " not provided or the wrong type"};
        }
    }
    return false;
}

module.exports = {
    jsonToUrlQuery    : jsonToUrlQuery,
    url               : url,
    withJSONFromBody  : withJSONFromBody,
    withFieldsChecked : withFieldsChecked
};

==> masm-util-0.0.3.tgz: package/main.js <==
var _ = require("underscore");

function jsonToUrlQuery(obj) {
    var query = [];
    _.each(obj, function(value, key) {
	query.push(key + "=" + encodeURIComponent(value));
    });
    return query.join("&");
}

function url(path, obj) {
    var query = jsonToUrlQuery(obj);
    if (query === "") {
        return path;
    } else {
        return path + "?" + query;
    }
}

function withJSONFromBody(callback) {
    return function(res) {
        var buffer = [];
        res.setEncoding("utf8");
        res.on("data", function(data) {
            buffer.push(data);
        });
        res.on("end", function() {
            var obj;
            try {
                obj = JSON.parse(buffer.join(""));
            } catch (e) {
                obj = { error: "internal server error", reason: "not an expected json body"};
            }
            callback(obj);
        });
    };
}

function withFieldsChecked(body, spec, callback) {
    return callback(checkFields(body, spec));
}

function checkFields(obj, fieldSpecs, type) {
    for (var i = 0; i < fieldSpecs.length; i++) {
        var fieldSpec = fieldSpecs[i];
        var fieldName, fieldType, cond, reason;
        cond   = fieldName = fieldSpec[0];
        reason = fieldType = fieldSpec[1];
        if (typeof cond == "boolean") {
            if (!cond) {
                return {error: "bad object", reason: reason};
            }
        } else if (typeof obj[fieldName] !== fieldType) {
            return {error: "bad object", reason: fieldName + " not provided or the wrong type"};
        }
    }
    return false;
}

function todo(str) {
    console.log("TODO: " + str);
}

function exitWithError(msg) {
    console.log("ERROR> " + msg);
    process.exit();
}

function log (msg) {
    return console.log(msg);
}

function logError (msg) {
    return console.log(msg);
}

function logStart (msg) {
    return console.log(msg);
}

function logEnd (msg) {
    return console.log("  " + msg);
}

function logFail (msg) {
    return console.log("  " + msg);
}

module.exports = {
    jsonToUrlQuery    : jsonToUrlQuery,
    url               : url,
    withJSONFromBody  : withJSONFromBody,
    withFieldsChecked : withFieldsChecked,
    todo              : todo,
    exitWithError     : exitWithError,
    log               : log,
    logError          : logError,
    logStart          : logStart,
    logEnd            : logEnd,
    logFail           : logFail
};
